introduction_nb

# Introduction¶

In [1]:

    from clustergrammer2 import net
    df = {}

    >> clustergrammer2 backend version 0.4.0

In [2]:

    net.load_file('rc_two_cats.txt')
    df['ini'] = net.export_df()

In [3]:

    net.load_df(df['ini'])
    net.widget()

In [4]:

    net.load_df(df['ini'])
    net.normalize(axis='row', norm_type='zscore')
    net.widget()

In [5]:

    import matplotlib.pyplot as plt

In [ ]:

In [ ]: